==> cms-db_v0.9.tar.gz: admin/editinc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('includes');
include('locale.inc.php');
$locale = new LocalizingClass('edit');
?>
<?php
if (isset($_POST['button']) && strpos($_POST['inc'], '/') === false) {
	include('escape.inc.php');
	//START
	$filename = '../data/includes/'.$_POST['inc'];
	$content = $_POST['content'];
	$content = escapeSL($content);
	if ($_POST['editmode'] == 'wysiwym') {
		require_once('mobile.inc.php');
		if (!supportscontenteditable()) {
			require_once('mobilemarkup.inc.php');
			$content = get_xhtml_from_mm($content);
		}
	} 
	if (is_writable($filename)) {

		if (!$handle = fopen($filename, "w")) {
			include('error.inc.php');
			throw_error(sprintf(locale('desc_error-open-file',true), $filename), 'editinc.php?inc='.$_POST['inc'].'&'.SID.csrf_protection_get());
		}

		if (!fwrite($handle, $content)) {
			include('error.inc.php');
			throw_error(sprintf(locale('desc_error-write-file',true), $filename), 'editinc.php?inc='.$_POST['inc'].'&'.SID.csrf_protection_get());
		}

		header('Location:includes.php?'.SID.csrf_protection_get());

		fclose($handle);

	} else {
		include('error.inc.php');
		throw_error(sprintf(locale('desc_error-fileperms',true), $filename), 'editinc.php?inc='.$_POST['inc'].'&'.SID.csrf_protection_get());
	}
	//END
} else {
	$editmode = (isset($_GET['editmode'])) ? $_GET['editmode'] : 'text';
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_editinc') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
<noscript><?php locale('desc_javascript') ?></noscript>
<?php
include('../functions_url.inc.php');
if ($editmode == 'wysiwym') {
	include('wymeditor.inc.php');
} elseif ($editmode == 'text') {
	echo '<script type="text/javascript" src="jquery.js"></script>';
	echo '<script type="text/javascript" src="jquery.textarea.js"></script>';
	echo '<script type="text/javascript">$(function () { $("textarea").tabby(); });</script>';
} elseif ($editmode == 'syntax') {
	$codemirror_type = 'php';
	include('codemirror.inc.php');
}
?>
</head>
<body>

<h1><?php locale('title_editinc') ?></h1>

<form action="editinc.php?<?php echo SID; csrf_protection_get_html() ?>" method="post">
	<input type="hidden" name="editmode" value="<?php echo $editmode ?>" />
	<input type="hidden" name="inc" value="<?php echo $_GET['inc'] ?>" />
	<p class="linklist_action">
		<?php
		$cssclass = ($editmode == 'text') ? ' active' : '';
		echo '<a class="nonewtab'.$cssclass.'" href="editinc.php?inc='.$_GET['inc'].'&amp;editmode=text&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('link_editmode-text',true).'</a>';
		$cssclass = ($editmode == 'syntax') ? ' active' : '';
		echo '<a class="nonewtab'.$cssclass.'" href="editinc.php?inc='.$_GET['inc'].'&amp;editmode=syntax&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('link_editmode-syntax',true).'</a>';
		$cssclass = ($editmode == 'wysiwym') ? ' active' : '';
		echo '<a class="nonewtab'.$cssclass.'" href="editinc.php?inc='.$_GET['inc'].'&amp;editmode=wysiwym&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('link_editmode-wysiwym',true).'</a>';
		?>
	</p>
	<div class="textarea <?php echo ($editmode == 'wysiwym' && !supportscontenteditable()) ? 'text' : $editmode ?>">
		<textarea class="wymeditor" id="content" name="content" cols="80" rows="20"><?php
		include('getcontent.inc.php');
		echo GetContent('../data/includes/'.$_GET['inc']);
		?></textarea>
	</div>
	<p>
		<div id="formbuttons">
			<input type="submit" name="button" value="<?php locale('button_save') ?>" class="wymupdate" />
		</div>
	</p>
</form>
<?php
if ($editmode == 'text') {
	include('insert.inc.php');
}
?>

</body>
</html>
<?php
}
?>

==> cms-db_v0.9.3.tar.gz: admin/editinc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

require_once('path.inc.php');
require_once(CDB_PATH_ADMIN.'/checkphp.inc.php');
require_once(CDB_PATH_ADMIN.'/checkuser.inc.php');

checkuser('includes');
require_once(CDB_PATH_ADMIN.'/locale.inc.php');
$locale = new LocalizingClass('edit');
?>
<?php
if (isset($_POST['button']) && strpos($_POST['inc'], '/') === false) {
	include('escape.inc.php');
	//START
	$filename = '../data/includes/'.$_POST['inc'];
	$content = $_POST['content'];
	$content = escapeSL($content);
	if ($_POST['editmode'] == 'wysiwym') {
		require_once('mobile.inc.php');
		if (!supportscontenteditable()) {
			require_once('mobilemarkup.inc.php');
			$content = get_xhtml_from_mm($content);
		}
	} 
	if (is_writable($filename)) {

		if (!$handle = fopen($filename, "w")) {
			include('error.inc.php');
			throw_error(sprintf(locale('desc_error-open-file',true), $filename), 'editinc.php?inc='.$_POST['inc'].'&'.SID.csrf_protection_get());
		}

		if (!fwrite($handle, $content)) {
			include('error.inc.php');
			throw_error(sprintf(locale('desc_error-write-file',true), $filename), 'editinc.php?inc='.$_POST['inc'].'&'.SID.csrf_protection_get());
		}

		header('Location:includes.php?'.SID.csrf_protection_get());

		fclose($handle);

	} else {
		include('error.inc.php');
		throw_error(sprintf(locale('desc_error-fileperms',true), $filename), 'editinc.php?inc='.$_POST['inc'].'&'.SID.csrf_protection_get());
	}
	//END
} else {
	$editmode = (isset($_GET['editmode'])) ? $_GET['editmode'] : 'text';
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_editinc') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
<noscript><?php locale('desc_javascript') ?></noscript>
<?php
include('../functions_url.inc.php');
if ($editmode == 'wysiwym') {
	include('wymeditor.inc.php');
} elseif ($editmode == 'text') {
	echo '<script type="text/javascript" src="jquery.js"></script>';
	echo '<script type="text/javascript" src="jquery.textarea.js"></script>';
	echo '<script type="text/javascript">$(function () { $("textarea").tabby(); });</script>';
} elseif ($editmode == 'syntax') {
	$codemirror_type = 'php';
	include('codemirror.inc.php');
}
?>
</head>
<body>

<h1><?php locale('title_editinc') ?></h1>

<form action="editinc.php?<?php echo SID; csrf_protection_get_html() ?>" method="post">
	<input type="hidden" name="editmode" value="<?php echo $editmode ?>" />
	<input type="hidden" name="inc" value="<?php echo $_GET['inc'] ?>" />
	<p class="linklist_action">
		<?php
		$cssclass = ($editmode == 'text') ? ' active' : '';
		echo '<a class="nonewtab'.$cssclass.'" href="editinc.php?inc='.$_GET['inc'].'&amp;editmode=text&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('link_editmode-text',true).'</a>';
		$cssclass = ($editmode == 'syntax') ? ' active' : '';
		echo '<a class="nonewtab'.$cssclass.'" href="editinc.php?inc='.$_GET['inc'].'&amp;editmode=syntax&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('link_editmode-syntax',true).'</a>';
		$cssclass = ($editmode == 'wysiwym') ? ' active' : '';
		echo '<a class="nonewtab'.$cssclass.'" href="editinc.php?inc='.$_GET['inc'].'&amp;editmode=wysiwym&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('link_editmode-wysiwym',true).'</a>';
		?>
	</p>
	<div class="textarea <?php echo ($editmode == 'wysiwym' && !supportscontenteditable()) ? 'text' : $editmode ?>">
		<textarea class="wymeditor" id="content" name="content" cols="80" rows="20"><?php
		include('getcontent.inc.php');
		echo GetContent('../data/includes/'.$_GET['inc']);
		?></textarea>
	</div>
	<p>
		<div id="formbuttons">
			<input type="submit" name="button" value="<?php locale('button_save') ?>" class="wymupdate" />
		</div>
	</p>
</form>
<?php
if ($editmode == 'text') {
	include('insert.inc.php');
}
?>

</body>
</html>
<?php
}
?>
